# English introduction
Student Information Management System —— Efficiently and standardizedly manage large amounts of student information based on the characteristics and actual needs of students, reducing the workload of school administrators

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 中文介绍
学生信息管理系统 ——针对学生信息特点及实际需要，高效率地、规范地管理大量学生信息，减轻学校管理人员的工作负担

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 用法
打开“可执行文件”文件夹下EXE文件即可，具体请阅读“学生信息管理系统使用说明.docx”
- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --- - - - - - -- ----
# bug反馈
### 如您在使用中发现任何问题，请访问作者[GitHub](https://github.com/CHUA-X/Student-Information-Management-System/issues "作者的GitHub")留言反馈，谢谢！
- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- - - - -
# 备注
### 从本处下载的学生信息管理系统可能无法运行，请移步[这里](https://github.com/CHUA-X/Student-Information-Management-System/archive/refs/heads/main.zip "下载地址")下载，多有不便请君谅解！